@@ -19,6 +19,9 @@
  */
 
 
+#include <glibmm/i18n.h>
+#include <gtkmm/stock.h>
+
 #include "ignote.hpp"
 #include "iconmanager.hpp"
 #include "notewindow.hpp"
@@ -27,6 +30,50 @@
 
 namespace backlinks {
 
+Glib::RefPtr<Gtk::Action> BacklinkAction::create(const sigc::slot<void, Gtk::Menu*> & slot)
+{
+  return Glib::RefPtr<Gtk::Action>(new BacklinkAction(slot));
+}
+
+BacklinkAction::BacklinkAction(const sigc::slot<void, Gtk::Menu*> & slot)
+  : Gtk::Action("BacklinkAction", Gtk::Stock::JUMP_TO,
+                _("What links here?"), _("Which notes have links to here?"))
+  , m_update_menu_slot(slot)
+{
+}
+
+Gtk::Widget *BacklinkAction::create_menu_item_vfunc()
+{
+  m_submenu_built = false;
+  Gtk::MenuItem *menu_item = new Gtk::ImageMenuItem;
+  m_menu = manage(new Gtk::Menu);
+  m_menu->signal_hide().connect(
+    sigc::mem_fun(*this, &BacklinkAction::on_menu_hidden));
+  menu_item->set_submenu(*m_menu);
+  return menu_item;
+}
+
+void BacklinkAction::on_activate()
+{
+  Gtk::Action::on_activate();
+  if(m_submenu_built) {
+    return;
+  }
+  update_menu();
+}
+
+void BacklinkAction::on_menu_hidden()
+{
+  m_submenu_built = false;
+}
+
+void BacklinkAction::update_menu()
+{
+  m_update_menu_slot(m_menu);
+  m_submenu_built = true;
+}
+
+
 Glib::RefPtr<Gdk::Pixbuf> BacklinkMenuItem::get_note_icon()
 {
   return gnote::IconManager::obj().get_icon(gnote::IconManager::NOTE, 16);
@@ -49,13 +96,6 @@ void BacklinkMenuItem::on_activate()
     return;
   }
 
-  // Show the title of the note
-  // where the user just came from.
-  gnote::NoteFindBar & find = m_note->get_window()->get_find_bar();
-  find.show_all ();
-  find.property_visible() = true;
-  find.set_search_text(m_title_search);
-  
   gnote::MainWindow *window = gnote::MainWindow::get_owning(*this);
   if(!window) {
     window = &gnote::IGnote::obj().new_main_window();
