@@ -27,6 +27,34 @@
 
 namespace replacetitle {
 
+  namespace {
+    class ReplaceTitleAction
+      : public Gtk::Action
+    {
+    public:
+      static Glib::RefPtr<Gtk::Action> create(gnote::NoteWindow *note_window)
+        {
+          return Glib::RefPtr<Gtk::Action>(new ReplaceTitleAction(note_window));
+        }
+    protected:
+      virtual Gtk::Widget *create_menu_item_vfunc()
+        {
+          Gtk::ImageMenuItem *menu_item = new Gtk::ImageMenuItem;
+          menu_item->add_accelerator("activate", m_note_window->get_accel_group(),
+                                     GDK_KEY_R, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+          return menu_item;
+        }
+    private:
+      ReplaceTitleAction(gnote::NoteWindow *note_window)
+        : Gtk::Action("ReplaceTitleAction", Gtk::Stock::FIND_AND_REPLACE,
+                      _("Replace title"), _("Replace title"))
+        , m_note_window(note_window)
+        {}
+
+      gnote::NoteWindow *m_note_window;
+    };
+  }
+
 
 ReplaceTitleModule::ReplaceTitleModule()
 {
@@ -44,34 +72,10 @@ void ReplaceTitleNoteAddin::shutdown()
 
 void ReplaceTitleNoteAddin::on_note_opened()
 {
-  m_menu_item = manage(new Gtk::ImageMenuItem(_("Replace title")));
-  m_menu_item->set_image(*manage(new Gtk::Image(Gtk::Stock::FIND_AND_REPLACE, Gtk::ICON_SIZE_MENU)));
-  m_menu_item->signal_activate().connect(
+  Glib::RefPtr<Gtk::Action> action = ReplaceTitleAction::create(get_window());
+  action->signal_activate().connect(
     sigc::mem_fun(*this, &ReplaceTitleNoteAddin::replacetitle_button_clicked));
-
-  gnote::NoteWindow *note_window = get_window();
-  note_window->signal_foregrounded.connect(
-    sigc::mem_fun(*this, &ReplaceTitleNoteAddin::on_note_foregrounded));
-  note_window->signal_backgrounded.connect(
-    sigc::mem_fun(*this, &ReplaceTitleNoteAddin::on_note_backgrounded));
-
-  m_menu_item->show() ;
-  add_plugin_menu_item(m_menu_item);
-}
-
-void ReplaceTitleNoteAddin::on_note_foregrounded()
-{
-  m_menu_item->add_accelerator("activate",
-                               get_window()->get_accel_group(),
-                               GDK_KEY_R,
-                               Gdk::CONTROL_MASK,
-                                Gtk::ACCEL_VISIBLE);
-}
-
-void ReplaceTitleNoteAddin::on_note_backgrounded()
-{
-  m_menu_item->remove_accelerator(get_window()->get_accel_group(),
-                                  GDK_KEY_R, Gdk::CONTROL_MASK);
+  add_note_action(action, 500);
 }
 
 void ReplaceTitleNoteAddin::replacetitle_button_clicked()
