@@ -49,14 +49,10 @@ public:
   virtual void add_main_window_search_action(const Glib::RefPtr<Gtk::Action> & action, int order) = 0;
   virtual void remove_main_window_search_action(const std::string & name) = 0;
   virtual std::vector<Glib::RefPtr<Gtk::Action> > get_main_window_search_actions() = 0;
-  virtual void add_main_window_note_action(const Glib::RefPtr<Gtk::Action> & action, int order) = 0;
-  virtual void remove_main_window_note_action(const std::string & name) = 0;
-  virtual std::vector<Glib::RefPtr<Gtk::Action> > get_main_window_note_actions() = 0;
   virtual const Glib::RefPtr<Gtk::UIManager> & get_ui() = 0;
   virtual Gtk::Widget * get_widget(const std::string &n) const = 0;
 
   sigc::signal<void> signal_main_window_search_actions_changed;
-  sigc::signal<void> signal_main_window_note_actions_changed;
 };
 
 }
