@@ -21,6 +21,7 @@
 #ifndef _MAINWINDOW_HPP_
 #define _MAINWINDOW_HPP_
 
+#include "mainwindowembeds.hpp"
 #include "note.hpp"
 #include "utils.hpp"
 
@@ -29,7 +30,7 @@ namespace gnote {
 
 class MainWindow
   : public utils::ForcedPresentWindow
-  , public utils::EmbeddableWidgetHost
+  , public EmbeddableWidgetHost
 {
 public:
   static MainWindow *get_owning(Gtk::Widget & widget);
@@ -38,6 +39,7 @@ public:
 
   virtual void set_search_text(const std::string & value) = 0;
   virtual void present_note(const Note::Ptr & note) = 0;
+  virtual void show_search_bar() = 0;
   virtual void present_search() = 0;
   virtual void new_note() = 0;
 };
