@@ -521,7 +521,7 @@ namespace gnote {
     title = split_title_from_content (title, body);
       
     if (title.empty()) {
-      title = get_unique_name(_("New Note"), m_notes.size());
+      title = get_unique_name(_("New Note"));
     }
 
     Note::Ptr template_note = get_or_create_template_note();
@@ -605,7 +605,7 @@ namespace gnote {
     if (!template_note) {
       std::string title = m_default_note_template_title;
       if (find(title)) {
-        title = get_unique_name(title, m_notes.size());
+        title = get_unique_name(title);
       }
       template_note =
         create (title,
@@ -715,7 +715,7 @@ namespace gnote {
     std::string new_title(title);
     Tag::Ptr template_save_title = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
     if(template_note->contains_tag(template_save_title)) {
-      new_title = get_unique_name(template_note->get_title(), m_notes.size());
+      new_title = get_unique_name(template_note->get_title());
     }
 
     // Use the body from the template note
@@ -755,10 +755,10 @@ namespace gnote {
     return new_note;
   }
 
-  // Find a title that does not exist using basename and id as
-  // a starting point
-  std::string NoteManager::get_unique_name(const std::string & basename, int id) const
+  // Find a title that does not exist using basename
+  std::string NoteManager::get_unique_name(const std::string & basename) const
   {
+    int id = 1;  // starting point
     std::string title;
     while (true) {
       title = str(boost::format("%1% %2%") % basename % id++);
