@@ -31,7 +31,6 @@
 #include <gtkmm/stock.h>
 
 #include "debug.hpp"
-#include "iactionmanager.hpp"
 #include "ignote.hpp"
 #include "iconmanager.hpp"
 #include "note.hpp"
@@ -47,12 +46,12 @@ namespace gnote {
     : MainWindow(_("Notes"))
     , m_note_manager(m)
     , m_search_notes_widget(m)
-    , m_content_vbox(false, 0)
+    , m_search_box(0.5, 0.5, 0.0, 1.0)
     , m_mapped(false)
     , m_entry_changed_timeout(NULL)
-    , m_window_menu_search(NULL)
-    , m_window_menu_note(NULL)
+    , m_window_menu_embedded(NULL)
     , m_window_menu_default(NULL)
+    , m_keybinder(get_accel_group())
   {
     set_default_size(450,400);
     set_resizable(true);
@@ -70,8 +69,13 @@ namespace gnote {
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_open_note_new_window));
 
     Gtk::Toolbar *toolbar = make_toolbar();
-    m_content_vbox.pack_start(*toolbar, false, false, 0);
-    m_content_vbox.pack_start(m_embed_box, true, true, 0);
+    make_search_box();
+    m_content_vbox.set_orientation(Gtk::ORIENTATION_VERTICAL);
+    m_content_vbox.attach(*toolbar, 0, 0, 1, 1);
+    m_content_vbox.attach(m_search_box, 0, 1, 1, 1);
+    m_content_vbox.attach(m_embed_box, 0, 2, 1, 1);
+    m_embed_box.set_hexpand(true);
+    m_embed_box.set_vexpand(true);
     m_embed_box.show();
     m_content_vbox.show ();
 
@@ -81,15 +85,11 @@ namespace gnote {
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_key_pressed));
     IGnote::obj().signal_quit
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_close_window));// to save size/pos
+    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::on_close_window),
+                                GDK_KEY_W, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
 
+    m_window_menu_default = make_window_menu(m_window_actions_button, std::vector<Gtk::MenuItem*>());
     embed_widget(m_search_notes_widget);
-
-    IActionManager::obj().signal_main_window_search_actions_changed
-      .connect(boost::bind(sigc::mem_fun(*this, &NoteRecentChanges::on_main_window_actions_changed),
-                           &m_window_menu_search));
-    IActionManager::obj().signal_main_window_note_actions_changed
-      .connect(boost::bind(sigc::mem_fun(*this, &NoteRecentChanges::on_main_window_actions_changed),
-                           &m_window_menu_note));
   }
 
 
@@ -101,11 +101,8 @@ namespace gnote {
     if(m_entry_changed_timeout) {
       delete m_entry_changed_timeout;
     }
-    if(m_window_menu_search) {
-      delete m_window_menu_search;
-    }
-    if(m_window_menu_note) {
-      delete m_window_menu_note;
+    if(m_window_menu_embedded) {
+      delete m_window_menu_embedded;
     }
     if(m_window_menu_default) {
       delete m_window_menu_default;
@@ -114,46 +111,74 @@ namespace gnote {
 
   Gtk::Toolbar *NoteRecentChanges::make_toolbar()
   {
+    gint icon_size = 16;
+    gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &icon_size, NULL);
     Gtk::Toolbar *toolbar = manage(new Gtk::Toolbar);
+    toolbar->set_hexpand(true);
+    toolbar->set_vexpand(false);
     // let move window by dragging toolbar with mouse
     toolbar->get_style_context()->add_class(GTK_STYLE_CLASS_MENUBAR);
     Gtk::ToolItem *tool_item = manage(new Gtk::ToolItem);
-    Gtk::Box *box = manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
-    box->set_border_width(5);
+    Gtk::Grid *box = manage(new Gtk::Grid);
+    box->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+
+    GtkIconSize toolbar_icon_size = gtk_toolbar_get_icon_size(toolbar->gobj());
+    gint toolbar_size_px;
+    gtk_icon_size_lookup(toolbar_icon_size, &toolbar_size_px, NULL);
+    gint icon_margin = (gint) floor((toolbar_size_px - icon_size) / 2.0);
+
+    Gtk::Grid *left_box = manage(new Gtk::Grid);
+    left_box->get_style_context()->add_class(GTK_STYLE_CLASS_RAISED);
+    left_box->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
     m_all_notes_button = manage(new Gtk::Button);
-    m_all_notes_button->set_image(*manage(new Gtk::Image(Gtk::Stock::FIND, Gtk::ICON_SIZE_BUTTON)));
-    m_all_notes_button->set_always_show_image(true);
-    m_all_notes_button->set_label(_("All Notes"));
+    Gtk::Image *image = manage(new Gtk::Image(IconManager::obj().get_icon("go-previous-symbolic", icon_size)));
+    image->property_margin() = icon_margin;
+    m_all_notes_button->set_image(*image);
+    m_all_notes_button->set_tooltip_text(_("All Notes"));
     m_all_notes_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteRecentChanges::present_search));
     m_all_notes_button->show_all();
-    box->pack_start(*m_all_notes_button, false, false);
+    left_box->attach(*m_all_notes_button, 0, 0, 1, 1);
 
-    Gtk::Button *button = manage(new Gtk::Button);
-    button->set_image(*manage(new Gtk::Image(IconManager::obj().get_icon(IconManager::NOTE_NEW, 24))));
-    button->set_always_show_image(true);
-    button->set_label(_("New"));
-    button->signal_clicked().connect(sigc::mem_fun(m_search_notes_widget, &SearchNotesWidget::new_note));
-    button->show_all();
-    box->pack_start(*button, false, false);
+    m_new_note_button = manage(new Gtk::Button);
+    m_new_note_button->set_vexpand(true);
+    m_new_note_button->set_label(_("New"));
+    m_new_note_button->add_accelerator("activate", get_accel_group(), GDK_KEY_N, Gdk::CONTROL_MASK, (Gtk::AccelFlags) 0);
+    m_new_note_button->signal_clicked().connect(sigc::mem_fun(m_search_notes_widget, &SearchNotesWidget::new_note));
+    m_new_note_button->show_all();
+    left_box->attach(*m_new_note_button, 1, 0, 1, 1);
+    left_box->show();
+    box->attach(*left_box, 0, 0, 1, 1);
 
-    m_search_entry.set_activates_default(false);
-    m_search_entry.set_size_request(300);
-    m_search_entry.signal_changed()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_changed));
-    m_search_entry.signal_activate()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_activated));
-    Gtk::Alignment *alignment = manage(new Gtk::Alignment(Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER, 0));
-    alignment->add(m_search_entry);
-    alignment->show_all();
-    box->pack_start(*alignment, true, true);
+    m_embedded_toolbar.set_hexpand(true);
+    m_embedded_toolbar.set_margin_left(6);
+    m_embedded_toolbar.set(0.0, 0.5, 0.0, 0.0);
+    m_embedded_toolbar.show();
+    box->attach(m_embedded_toolbar, 1, 0, 1, 1);
 
-    button = manage(new Gtk::Button);
-    button->set_image(*manage(new Gtk::Image(IconManager::obj().get_icon("emblem-system-symbolic", 24))));
-    button->set_always_show_image(true);
-    button->signal_clicked().connect(
-      boost::bind(sigc::mem_fun(*this, &NoteRecentChanges::on_show_window_menu), button));
-    button->show_all();
-    box->pack_end(*button, false, false);
+    Gtk::Grid *right_box = manage(new Gtk::Grid);
+    right_box->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+    right_box->set_column_spacing(5);
+    image = manage(new Gtk::Image(IconManager::obj().get_icon("edit-find-symbolic", icon_size)));
+    image->property_margin() = icon_margin;
+    m_search_button.set_image(*image);
+    m_search_button.signal_toggled().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_search_button_toggled));
+    m_search_button.add_accelerator("activate", get_accel_group(), GDK_KEY_F, Gdk::CONTROL_MASK, (Gtk::AccelFlags) 0);
+    m_search_button.set_tooltip_text(_("Search"));
+    m_search_button.show_all();
+    right_box->attach(m_search_button, 0, 0, 1, 1);
+
+    m_window_actions_button = manage(new Gtk::Button);
+    image = manage(new Gtk::Image(IconManager::obj().get_icon("emblem-system-symbolic", icon_size)));
+    image->property_margin() = icon_margin;
+    m_window_actions_button->set_image(*image);
+    m_window_actions_button->signal_clicked().connect(
+      sigc::mem_fun(*this, &NoteRecentChanges::on_show_window_menu));
+    m_window_actions_button->add_accelerator(
+      "activate", get_accel_group(), GDK_KEY_F10, (Gdk::ModifierType) 0, (Gtk::AccelFlags) 0);
+    m_window_actions_button->show_all();
+    right_box->attach(*m_window_actions_button, 1, 0, 1, 1);
+    right_box->show();
+    box->attach(*right_box, 2, 0, 1, 1);
 
     box->show();
     tool_item->add(*box);
@@ -164,9 +189,93 @@ namespace gnote {
     return toolbar;
   }
 
+  void NoteRecentChanges::make_search_box()
+  {
+    m_search_entry.set_activates_default(false);
+    m_search_entry.set_size_request(300);
+    m_search_entry.signal_changed()
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_changed));
+    m_search_entry.signal_activate()
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_activated));
+    m_search_entry.show();
+
+    Gtk::Grid *grid = manage(new Gtk::Grid);
+    grid->set_margin_left(5);
+    grid->set_margin_right(5);
+    grid->set_hexpand(false);
+    grid->attach(m_search_entry, 0, 0, 1, 1);
+
+    m_find_next_prev_box.set_margin_left(5);
+
+    Gtk::Button *find_next_button = manage(new Gtk::Button(_("Find _Next"), true));
+    find_next_button->set_image(*manage(new Gtk::Image(Gtk::Stock::GO_FORWARD, Gtk::ICON_SIZE_MENU)));
+    find_next_button->set_always_show_image(true);
+    find_next_button->signal_clicked()
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_find_next_button_clicked));
+    find_next_button->show();
+    m_find_next_prev_box.attach(*find_next_button, 0, 0, 1, 1);
+
+    Gtk::Button *find_prev_button = manage(new Gtk::Button(_("Find _Previous"), true));
+    find_prev_button->set_image(*manage(new Gtk::Image(Gtk::Stock::GO_BACK, Gtk::ICON_SIZE_MENU)));
+    find_prev_button->set_always_show_image(true);
+    find_prev_button->signal_clicked()
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_find_prev_button_clicked));
+    find_prev_button->show();
+    m_find_next_prev_box.attach(*find_prev_button, 1, 0, 1, 1);
+
+    grid->attach(m_find_next_prev_box, 1, 0, 1, 1);
+    grid->show();
+
+    m_search_box.add(*grid);
+    m_search_box.set_hexpand(true);
+  }
+
+  void NoteRecentChanges::on_search_button_toggled()
+  {
+    if(m_search_button.get_active()) {
+      show_search_bar();
+    }
+    else {
+      m_search_box.hide();
+      SearchableItem *searchable_widget = dynamic_cast<SearchableItem*>(currently_embedded());
+      if(searchable_widget) {
+        searchable_widget->perform_search("");
+      }
+    }
+  }
+
+  void NoteRecentChanges::on_find_next_button_clicked()
+  {
+    SearchableItem *searchable_widget = dynamic_cast<SearchableItem*>(currently_embedded());
+    if(searchable_widget) {
+      searchable_widget->goto_next_result();
+    }
+  }
+
+  void NoteRecentChanges::on_find_prev_button_clicked()
+  {
+    SearchableItem *searchable_widget = dynamic_cast<SearchableItem*>(currently_embedded());
+    if(searchable_widget) {
+      searchable_widget->goto_previous_result();
+    }
+  }
+
+  void NoteRecentChanges::show_search_bar()
+  {
+    m_search_box.show();
+    m_search_entry.grab_focus();
+    Glib::ustring text = m_search_entry.get_text();
+    if(text != "") {
+      SearchableItem *searchable_widget = dynamic_cast<SearchableItem*>(currently_embedded());
+      if(searchable_widget) {
+        searchable_widget->perform_search(text);
+      }
+    }
+  }
+
   void NoteRecentChanges::present_search()
   {
-    utils::EmbeddableWidget *current = currently_embedded();
+    EmbeddableWidget *current = currently_embedded();
     if(&m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(current)) {
       return;
     }
@@ -222,7 +331,7 @@ namespace gnote {
     std::vector<Gtk::Widget*> current = m_embed_box.get_children();
     for(std::vector<Gtk::Widget*>::iterator iter = current.begin();
         iter != current.end(); ++iter) {
-      utils::EmbeddableWidget *widget = dynamic_cast<utils::EmbeddableWidget*>(*iter);
+      EmbeddableWidget *widget = dynamic_cast<EmbeddableWidget*>(*iter);
       if(widget) {
         background_embedded(*widget);
       }
@@ -242,12 +351,16 @@ namespace gnote {
   {
     switch (ev->keyval) {
     case GDK_KEY_Escape:
+      if(m_search_button.get_active()) {
+        m_search_entry.set_text("");
+        m_search_button.set_active(false);
+      }
       // Allow Escape to close the window
-      if(&m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(currently_embedded())) {
+      else if(&m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(currently_embedded())) {
         on_close_window();
       }
       else {
-        utils::EmbeddableWidget *current_item = currently_embedded();
+        EmbeddableWidget *current_item = currently_embedded();
         if(current_item) {
           background_embedded(*current_item);
         }
@@ -269,14 +382,21 @@ namespace gnote {
     // Select "All Notes" in the notebooks list
     m_search_notes_widget.select_all_notes_notebook();
 
+    EmbeddableWidget *widget = NULL;
     if(m_embed_box.get_children().size() == 0 && m_embedded_widgets.size() > 0) {
-      foreground_embedded(**m_embedded_widgets.rbegin());
-    }
-    std::vector<Gtk::Widget*> embedded = m_embed_box.get_children();
-    if(embedded.size() == 1 && embedded.front() == &m_search_notes_widget) {
-      m_search_entry.grab_focus();
+      widget = *m_embedded_widgets.rbegin();
+      foreground_embedded(*widget);
     }
+
     MainWindow::on_show();
+
+    if(widget) {
+      int x = 0, y = 0;
+      widget->hint_position(x, y);
+      if(x && y) {
+        move(x, y);
+      }
+    }
   }
 
   void NoteRecentChanges::set_search_text(const std::string & value)
@@ -284,23 +404,29 @@ namespace gnote {
     m_search_entry.set_text(value);
   }
 
-  void NoteRecentChanges::embed_widget(utils::EmbeddableWidget & widget)
+  void NoteRecentChanges::embed_widget(EmbeddableWidget & widget)
   {
     if(std::find(m_embedded_widgets.begin(), m_embedded_widgets.end(), &widget) == m_embedded_widgets.end()) {
       widget.embed(this);
       m_embedded_widgets.push_back(&widget);
     }
-    utils::EmbeddableWidget *current = currently_embedded();
-    if(current && current != &widget) {
+    EmbeddableWidget *current = currently_embedded();
+    if(current == &widget) {
+      return;
+    }
+    if(current) {
       background_embedded(*current);
     }
-    foreground_embedded(widget);
+
+   if(get_visible()) {
+      foreground_embedded(widget);
+    }
   }
 
-  void NoteRecentChanges::unembed_widget(utils::EmbeddableWidget & widget)
+  void NoteRecentChanges::unembed_widget(EmbeddableWidget & widget)
   {
     bool show_other = false;
-    std::list<utils::EmbeddableWidget*>::iterator iter = std::find(
+    std::list<EmbeddableWidget*>::iterator iter = std::find(
       m_embedded_widgets.begin(), m_embedded_widgets.end(), &widget);
     if(iter != m_embedded_widgets.end()) {
       if(is_foreground(**iter)) {
@@ -320,16 +446,33 @@ namespace gnote {
     }
   }
 
-  void NoteRecentChanges::foreground_embedded(utils::EmbeddableWidget & widget)
+  void NoteRecentChanges::foreground_embedded(EmbeddableWidget & widget)
   {
     try {
       if(currently_embedded() == &widget) {
         return;
       }
       Gtk::Widget &wid = dynamic_cast<Gtk::Widget&>(widget);
-      m_embed_box.pack_start(wid, true, true, 0);
-      widget.foreground();
+      m_embed_box.add(wid);
       wid.show();
+      widget.foreground();
+
+      bool maximized = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
+        Preferences::MAIN_WINDOW_MAXIMIZED);
+      if(get_realized()) {
+        //if window is showing, use actual state
+        maximized = get_window()->get_state() & Gdk::WINDOW_STATE_MAXIMIZED;
+      }
+      int width = 0, height = 0;
+      widget.hint_size(width, height);
+      if(width && height) {
+        set_default_size(width, height);
+        if(!maximized && get_visible()) {
+          get_window()->resize(width, height);
+        }
+      }
+      widget.size_internals();
+ 
       update_toolbar(widget);
       on_embedded_name_changed(widget.get_name());
       m_current_embedded_name_slot = widget.signal_name_changed
@@ -337,9 +480,19 @@ namespace gnote {
     }
     catch(std::bad_cast&) {
     }
+
+    try {
+      HasActions &has_actions = dynamic_cast<HasActions&>(widget);
+      m_current_embedded_actions_slot = has_actions.signal_actions_changed().connect(
+        boost::bind(sigc::mem_fun(*this, &NoteRecentChanges::on_main_window_actions_changed),
+                    &m_window_menu_embedded));
+      on_main_window_actions_changed(&m_window_menu_embedded);
+    }
+    catch(std::bad_cast&) {
+    }
   }
 
-  void NoteRecentChanges::background_embedded(utils::EmbeddableWidget & widget)
+  void NoteRecentChanges::background_embedded(EmbeddableWidget & widget)
   {
     try {
       if(currently_embedded() != &widget) {
@@ -349,17 +502,25 @@ namespace gnote {
       Gtk::Widget &wid = dynamic_cast<Gtk::Widget&>(widget);
       widget.background();
       m_embed_box.remove(wid);
+
+      m_current_embedded_actions_slot.disconnect();
+      if(m_window_menu_embedded) {
+        delete m_window_menu_embedded;
+        m_window_menu_embedded = NULL;
+      }
     }
     catch(std::bad_cast&) {
     }
+
+    m_embedded_toolbar.remove();
   }
 
-  bool NoteRecentChanges::is_foreground(utils::EmbeddableWidget & widget)
+  bool NoteRecentChanges::is_foreground(EmbeddableWidget & widget)
   {
     std::vector<Gtk::Widget*> current = m_embed_box.get_children();
     for(std::vector<Gtk::Widget*>::iterator iter = current.begin();
         iter != current.end(); ++iter) {
-      if(dynamic_cast<utils::EmbeddableWidget*>(*iter) == &widget) {
+      if(dynamic_cast<EmbeddableWidget*>(*iter) == &widget) {
         return true;
       }
     }
@@ -367,10 +528,10 @@ namespace gnote {
     return false;
   }
 
-  utils::EmbeddableWidget *NoteRecentChanges::currently_embedded()
+  EmbeddableWidget *NoteRecentChanges::currently_embedded()
   {
     std::vector<Gtk::Widget*> children = m_embed_box.get_children();
-    return children.size() ? dynamic_cast<utils::EmbeddableWidget*>(children[0]) : NULL;
+    return children.size() ? dynamic_cast<EmbeddableWidget*>(children[0]) : NULL;
   }
 
   bool NoteRecentChanges::on_map_event(GdkEventAny *evt)
@@ -392,6 +553,9 @@ namespace gnote {
 
   void NoteRecentChanges::on_entry_changed()
   {
+    if(!m_search_box.get_visible()) {
+      return;
+    }
     if(m_entry_changed_timeout == NULL) {
       m_entry_changed_timeout = new utils::InterruptableTimeout();
       m_entry_changed_timeout->signal_timeout
@@ -400,7 +564,10 @@ namespace gnote {
 
     std::string search_text = get_search_text();
     if(search_text.empty()) {
-      m_search_notes_widget.perform_search(search_text);
+      SearchableItem *searchable_widget = dynamic_cast<SearchableItem*>(currently_embedded());
+      if(searchable_widget) {
+        searchable_widget->perform_search(search_text);
+      }
     }
     else {
       m_entry_changed_timeout->reset(500);
@@ -418,12 +585,18 @@ namespace gnote {
 
   void NoteRecentChanges::entry_changed_timeout()
   {
+    if(!m_search_box.get_visible()) {
+      return;
+    }
     std::string search_text = get_search_text();
     if(search_text.empty()) {
       return;
     }
 
-    m_search_notes_widget.perform_search(search_text);
+    SearchableItem *searchable_widget = dynamic_cast<SearchableItem*>(currently_embedded());
+    if(searchable_widget) {
+      searchable_widget->perform_search(search_text);
+    }
   }
 
   std::string NoteRecentChanges::get_search_text()
@@ -433,34 +606,48 @@ namespace gnote {
     return text;
   }
 
-  void NoteRecentChanges::update_toolbar(utils::EmbeddableWidget & widget)
+  void NoteRecentChanges::update_toolbar(EmbeddableWidget & widget)
   {
     bool search = dynamic_cast<SearchNotesWidget*>(&widget) == &m_search_notes_widget;
-    m_all_notes_button->set_sensitive(!search);
-    m_search_entry.set_visible(search);
+    m_all_notes_button->set_visible(!search);
+    m_new_note_button->set_visible(search);
+
+    try {
+      SearchableItem & searchable_item = dynamic_cast<SearchableItem&>(widget);
+      m_search_button.show();
+      if(searchable_item.supports_goto_result()) {
+        m_find_next_prev_box.show();
+      }
+      else {
+        m_find_next_prev_box.hide();
+      }
+      if(m_search_button.get_active() && m_search_entry.get_text() != "") {
+        searchable_item.perform_search(m_search_entry.get_text());
+      }
+    }
+    catch(std::bad_cast &) {
+      m_search_button.set_active(false);
+      m_search_button.hide();
+    }
+
+    try {
+      HasEmbeddableToolbar & toolbar_provider = dynamic_cast<HasEmbeddableToolbar&>(widget);
+      Gtk::Widget *tool_item = toolbar_provider.embeddable_toolbar();
+      if(tool_item) {
+        m_embedded_toolbar.add(*tool_item);
+      }
+    }
+    catch(std::bad_cast &) {
+    }
   }
 
-  void NoteRecentChanges::on_show_window_menu(Gtk::Button *button)
+  void NoteRecentChanges::on_show_window_menu()
   {
-    std::vector<Gtk::MenuItem*> items;
-    if(dynamic_cast<SearchNotesWidget*>(currently_embedded()) == &m_search_notes_widget) {
-      if(!m_window_menu_search) {
-        m_window_menu_search = make_window_menu(button,
-            make_menu_items(items, IActionManager::obj().get_main_window_search_actions()));
-      }
-      utils::popup_menu(*m_window_menu_search, NULL);
-    }
-    else if(dynamic_cast<NoteWindow*>(currently_embedded())) {
-      if(!m_window_menu_note) {
-        m_window_menu_note = make_window_menu(button,
-            make_menu_items(items, IActionManager::obj().get_main_window_note_actions()));
-      }
-      utils::popup_menu(*m_window_menu_note, NULL);
+    HasActions *embed_with_actions = dynamic_cast<HasActions*>(currently_embedded());
+    if(embed_with_actions) {
+      utils::popup_menu(*m_window_menu_embedded, NULL);
     }
     else {
-      if(!m_window_menu_default) {
-        m_window_menu_default = make_window_menu(button, items);
-      }
       utils::popup_menu(*m_window_menu_default, NULL);
     }
   }
@@ -475,6 +662,7 @@ namespace gnote {
       menu->append(*manage(new Gtk::SeparatorMenuItem));
     }
     Gtk::MenuItem *item = manage(new Gtk::MenuItem(_("_Close"), true));
+    item->add_accelerator("activate", get_accel_group(), GDK_KEY_W, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     item->signal_activate().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_close_window));
     menu->append(*item);
     menu->property_attach_widget() = button;
@@ -486,8 +674,7 @@ namespace gnote {
     const std::vector<Glib::RefPtr<Gtk::Action> > & actions)
   {
     for(std::vector<Glib::RefPtr<Gtk::Action> >::const_iterator iter = actions.begin(); iter != actions.end(); ++iter) {
-      Gtk::MenuItem *item = manage(new Gtk::MenuItem);
-      item->set_related_action(*iter);
+      Gtk::MenuItem *item = manage((*iter)->create_menu_item());
       items.push_back(item);
     }
     return items;
@@ -499,6 +686,15 @@ namespace gnote {
       delete *menu;
       *menu = NULL;
     }
+
+    HasActions *embed_with_actions = dynamic_cast<HasActions*>(currently_embedded());
+    if(embed_with_actions) {
+      if(!m_window_menu_embedded) {
+        std::vector<Gtk::MenuItem*> items;
+        m_window_menu_embedded = make_window_menu(m_window_actions_button,
+          make_menu_items(items, embed_with_actions->get_widget_actions()));
+      }
+    }
   }
 
 }
