@@ -26,8 +26,9 @@
 
 #include <string>
 
-#include <gtkmm/radiomenuitem.h>
+#include <gtkmm/alignment.h>
 #include <gtkmm/applicationwindow.h>
+#include <gtkmm/grid.h>
 
 #include "note.hpp"
 #include "searchnoteswidget.hpp"
@@ -42,15 +43,16 @@ class NoteRecentChanges
 public:
   NoteRecentChanges(NoteManager& m);
   virtual ~NoteRecentChanges();
+  virtual void show_search_bar();
   virtual void set_search_text(const std::string & value);
   virtual void present_note(const Note::Ptr & note);
   virtual void new_note();
   virtual void present_search();
 
-  virtual void embed_widget(utils::EmbeddableWidget &);
-  virtual void unembed_widget(utils::EmbeddableWidget &);
-  virtual void foreground_embedded(utils::EmbeddableWidget &);
-  virtual void background_embedded(utils::EmbeddableWidget &);
+  virtual void embed_widget(EmbeddableWidget &);
+  virtual void unembed_widget(EmbeddableWidget &);
+  virtual void foreground_embedded(EmbeddableWidget &);
+  virtual void background_embedded(EmbeddableWidget &);
   virtual bool running()
     {
       return m_mapped;
@@ -65,16 +67,20 @@ private:
   void on_close_window();
   bool on_delete(GdkEventAny *);
   bool on_key_pressed(GdkEventKey *);
-  bool is_foreground(utils::EmbeddableWidget &);
-  utils::EmbeddableWidget *currently_embedded();
+  bool is_foreground(EmbeddableWidget &);
+  EmbeddableWidget *currently_embedded();
   Gtk::Toolbar *make_toolbar();
+  void make_search_box();
   void on_embedded_name_changed(const std::string & name);
   void on_entry_changed();
   void on_entry_activated();
   void entry_changed_timeout();
   std::string get_search_text();
-  void update_toolbar(utils::EmbeddableWidget & widget);
-  void on_show_window_menu(Gtk::Button *button);
+  void update_toolbar(EmbeddableWidget & widget);
+  void on_show_window_menu();
+  void on_search_button_toggled();
+  void on_find_next_button_clicked();
+  void on_find_prev_button_clicked();
   Gtk::Menu *make_window_menu(Gtk::Button *button, const std::vector<Gtk::MenuItem*> & items);
   std::vector<Gtk::MenuItem*> & make_menu_items(std::vector<Gtk::MenuItem*> & items,
                                                 const std::vector<Glib::RefPtr<Gtk::Action> > & actions);
@@ -82,17 +88,24 @@ private:
 
   NoteManager        &m_note_manager;
   SearchNotesWidget   m_search_notes_widget;
-  Gtk::VBox           m_content_vbox;
-  Gtk::VBox           m_embed_box;
+  Gtk::Grid           m_content_vbox;
+  Gtk::Alignment      m_search_box;
+  Gtk::Grid           m_find_next_prev_box;
+  Gtk::ToggleButton   m_search_button;
+  Gtk::Alignment      m_embedded_toolbar;
+  Gtk::Grid           m_embed_box;
   Gtk::Button        *m_all_notes_button;
+  Gtk::Button        *m_new_note_button;
+  Gtk::Button        *m_window_actions_button;
   Gtk::SearchEntry    m_search_entry;
-  std::list<utils::EmbeddableWidget*> m_embedded_widgets;
+  std::list<EmbeddableWidget*> m_embedded_widgets;
   bool                m_mapped;
   sigc::connection    m_current_embedded_name_slot;
+  sigc::connection    m_current_embedded_actions_slot;
   utils::InterruptableTimeout *m_entry_changed_timeout;
-  Gtk::Menu          *m_window_menu_search;
-  Gtk::Menu          *m_window_menu_note;
+  Gtk::Menu          *m_window_menu_embedded;
   Gtk::Menu          *m_window_menu_default;
+  utils::GlobalKeybinder m_keybinder;
 };
 
 
